==> nextcloud-29.0.12.tgz: nextcloud/apps/files_downloadlimit/l10n/uk.js <==
OC.L10N.register(
    "files_downloadlimit",
    {
    "Files download limit" : "Обмеження на звантаження файлів",
    "File link share download limit" : "Обмеження на звантаження файлу за посиланням",
    "Limit downloads" : "Обмежити звантаження",
    "Set download limit" : "Встановити обмеження на звантаження",
    "_1 remaining download allowed_::_{count} remaining downloads allowed_" : ["Дозволено ще 1 завантаження","Залишилося завантажень: {count}","Залишилося завантажень: {count}","Дозволена кількість звантажень: {count}"],
    "Download limit" : "Обмеження на звантаження",
    "Configure the default download limit for external shares." : "Налаштуйте типове обмеження на звантаження для зовнішніх спільних ресурсів.",
    "Set default download limit" : "Встановити типове обмеження на звантаження",
    "Failed to set default download limit" : "Не вдалося встановити типове обмеження на звантаження",
    "You have reached the maximum amount of downloads allowed" : "Ви досягли максимально дозволеної кількості звантажень",
    "This share has a limited number of downloads. Are you sure you want to trigger a new download?" : "Цей ресурс має обмежену кількість звантажень. Ви впевнені, що хочете запустити нове завантаження?"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");

==> nextcloud-30.0.15.tgz: nextcloud/apps/files_downloadlimit/l10n/uk.js <==
OC.L10N.register(
    "files_downloadlimit",
    {
    "Files download limit" : "Обмеження на звантаження файлів",
    "File link share download limit" : "Обмеження на звантаження файлу за посиланням",
    "This app allows limiting the number of downloads for external link shares." : "Ця програма дозволяє обмежити кількість завантажень для зовнішніх посилань.",
    "The minimum limit is 1" : "Мінімальний ліміт становить 1",
    "Failed to set download limit" : "Не вдалося встановити обмеження на завантаження",
    "Failed to remove download limit" : "Не вдалося зняти обмеження на завантаження",
    "Limit downloads" : "Обмежити звантаження",
    "Set download limit" : "Встановити обмеження на звантаження",
    "Setting a new limit will reset the download count" : "Встановлення нового обмеження призведе до скидання лічильника завантажень.",
    "_1 remaining download allowed_::_{count} remaining downloads allowed_" : ["Дозволено ще 1 завантаження","Залишилося завантажень: {count}","Залишилося завантажень: {count}","Дозволена кількість звантажень: {count}"],
    "Failed to set default download limit" : "Не вдалося встановити типове обмеження на звантаження",
    "Download limit" : "Обмеження на звантаження",
    "Configure the default download limit for external shares." : "Налаштуйте типове обмеження на звантаження для зовнішніх спільних ресурсів.",
    "Set default download limit" : "Встановити типове обмеження на звантаження",
    "You have reached the maximum amount of downloads allowed" : "Ви досягли максимально дозволеної кількості звантажень",
    "This share has a limited number of downloads. Are you sure you want to trigger a new download?" : "Цей ресурс має обмежену кількість звантажень. Ви впевнені, що хочете запустити нове завантаження?"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
